import java.io.*;
import java.net.*;
import com.sun.net.httpserver.*;

import java.util.logging.*;


public class Server {

	// STATIC MEMBERS
    private static final int MAX_WAITING_CONNECTIONS = 12;

    private static Logger logger;

    static {
        try {
            initLog();
        }
        catch (IOException e) {
            System.out.println("Could not initialize log: " + e.getMessage());
			e.printStackTrace();
        }
    }
	
    private static void initLog() throws IOException {

        Level logLevel = Level.FINEST;

        logger = Logger.getLogger("tickettoride"); 
        logger.setLevel(logLevel);
        logger.setUseParentHandlers(false);

        Handler consoleHandler = new ConsoleHandler();
        consoleHandler.setLevel(logLevel);
        consoleHandler.setFormatter(new SimpleFormatter());
        logger.addHandler(consoleHandler);

        FileHandler fileHandler = new FileHandler("log.txt", false);
        fileHandler.setLevel(logLevel);
        fileHandler.setFormatter(new SimpleFormatter());
        logger.addHandler(fileHandler);
    }
	
	
	// NON-STATIC MEMBERS
    private HttpServer server;

    private void run(String portNumber) {

        logger.info("Initializing HTTP Server");
        try {
            server = HttpServer.create(
					new InetSocketAddress(Integer.parseInt(portNumber)),
                    MAX_WAITING_CONNECTIONS);
        }
        catch (IOException e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
            return;
        }

        server.setExecutor(null); // use the default executor

        logger.info("Creating contexts");
        server.createContext("/games/list", new ListGamesHandler());
		server.createContext("/routes/claim", new ClaimRouteHandler());
		
        logger.info("Starting HTTP server");
        server.start();
    }

    public static void main(String[] args) {		
		String portNumber = args[0];
        new Server().run(portNumber);
    }
}

